#' ---
#' title: |
#'   ２因子実験（質的因子×質的因子） \
#'   最小２乗平均の利用 \
#'   SampleLSMean.R
#' author: "Masahiko Katase"
#' date: "20221/2/21"
#' ---

#+ message = FALSE
library(readxl)    # read_excel
library(car)       # Anova
library(emmeans)   # emmeans
library(phia)      # interactionMeans

#'# データ
df <- read_excel("DataFileLSM.xlsx", sheet = "Sheet1")

df   <- data.frame(df)
df$A <- factor(df$A)
df$B <- factor(df$B)
str(df)

#'# グラフ
interaction.plot(
  x.factor     = df$A,        # x軸
  trace.factor = df$B,        # 区別する変数
  response     = df$y,        # y軸
  fun          = mean,        # 平均値をプロット
  type         = "b",         # 点と線のグラフ
  legend       = TRUE,        # 凡例を表示
  ylim         = c(100, 120), # y軸の範囲
  xlab         = "A",         # x軸のタイトル
  ylab         = "y",         # y軸のタイトル
  trace.label  = "B",         # 凡例での区別するタイトル
  pch          = c(1, 2),     # 点の記号の種類
  cex.lab      = 1            # 軸タイトルの文字サイズ
)

#'# モデルのあてはめ
lm_out <- lm(y ~ A + B + A:B, data = df, 
             contrasts = list(A = "contr.sum", 
                              B = "contr.sum"))
summary(lm_out)
Anova(lm_out, type = 3)

#'# 最小２乗平均 
emm_options(opt.digits = FALSE)  # 表示する桁の丸めを解除

## 因子A の水準の最小２乗平均
emmeans(lm_out, specs = ~ A)

## ２因子の水準組み合わせの比較（多重比較：Tukeyの方法）
emm_out <- emmeans(lm_out, specs = pairwise ~ A:B,
                   adjust = "tukey")
emm_out$emmeans
emm_out$contrasts
confint(emm_out$contrasts)
summary(emm_out$contrasts, infer = TRUE)

## 因子Bごとに因子Aの水準を比較（多重比較：Tukeyの方法）
emmeans(lm_out, specs = pairwise ~ A|B, adjust = "tukey")

## 因子Bを合わせて因子Aの水準を比較（多重比較：Tukeyの方法）
emmeans(lm_out, specs = pairwise ~ A, adjust = "tukey")

## ２要因のすべての組み合わせにおける対照（A1B1）との比較
##（多重比較：Dunnettの方法）
emmeans(lm_out, specs = trt.vs.ctrl ~ A:B)

#'# グラフ
phia_out <- interactionMeans(lm_out)
phia_out
plot(phia_out)